From db@blackbox.site Wed Jun 29 08:17:20 2005
Date: Wed, 29 Jun 2005 07:04:14 -0700
From: david-b@pacbell.net
To: gregkh@kroah.com
Subject: USB: another cdc descriptor
Message-Id: <20050629140414.84FC9C894D@blackbox.site>

This adds another CDC descriptor type to <linux/usb_cdc.h>; the main claim
to fame for this is that some Motorola phones include it.  It's not currently
needed by any driver code; included for completeness.

Signed-off-by: David Brownell <dbrownell@users.sourceforge.net>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 include/linux/usb_cdc.h |   13 +++++++++++++
 1 files changed, 13 insertions(+)

--- gregkh-2.6.orig/include/linux/usb_cdc.h	2005-06-17 12:48:29.000000000 -0700
+++ gregkh-2.6/include/linux/usb_cdc.h	2005-07-01 14:18:12.000000000 -0700
@@ -34,6 +34,7 @@
 #define USB_CDC_ACM_TYPE		0x02		/* acm_descriptor */
 #define USB_CDC_UNION_TYPE		0x06		/* union_desc */
 #define USB_CDC_COUNTRY_TYPE		0x07
+#define USB_CDC_NETWORK_TERMINAL_TYPE	0x0a		/* network_terminal_desc */
 #define USB_CDC_ETHERNET_TYPE		0x0f		/* ether_desc */
 #define USB_CDC_WHCM_TYPE		0x11
 #define USB_CDC_MDLM_TYPE		0x12		/* mdlm_desc */
@@ -83,6 +84,18 @@
 	/* ... and there could be other slave interfaces */
 } __attribute__ ((packed));
 
+/* "Network Channel Terminal Functional Descriptor" from CDC spec 5.2.3.11 */
+struct usb_cdc_network_terminal_desc {
+	__u8	bLength;
+	__u8	bDescriptorType;
+	__u8	bDescriptorSubType;
+
+	__u8	bEntityId;
+	__u8	iName;
+	__u8	bChannelIndex;
+	__u8	bPhysicalInterface;
+} __attribute__ ((packed));
+
 /* "Ethernet Networking Functional Descriptor" from CDC spec 5.2.3.16 */
 struct usb_cdc_ether_desc {
 	__u8	bLength;
